@@ -1,4 +1,4 @@
 from .acchorder import Acchorder
 from .chord import Chord
-from .dechorder import get_key_from_pitch, Dechorder
+from .dechorder import get_key_from_pitch, Dechorder, chord_to_midi, play_chords
 from .timepoints import *
