@@ -74,10 +74,10 @@ class Acchorder:
 
             if note.pitch in bass_candidates:
                 bass_index = bass_candidates.index(note.pitch)
-                if progression[start_beat + bass_index][2] is None:
+                if progression[start_beat + bass_index].bass_pc is None:
                     continue
 
-                new_pitch = progression[start_beat + bass_index][2] + (pitch // 12) * 12 + key
+                new_pitch = progression[start_beat + bass_index].bass_pc + (pitch // 12) * 12 + key
                 new_note = note
                 new_note.pitch = new_pitch
                 new_notes.append(new_note)
@@ -92,27 +92,19 @@ class Acchorder:
                 time_weights[-1] = note.end - end_beat * interval
 
             for beat in range(start_beat, end_beat + 1):
-                root, quality, bass, score = progression[beat]
-                if root < 0:
+                chord = progression[beat]
+                if not chord.is_complete():
                     candidate_lists.append([])
                     continue
+                root, quality, bass = chord.root_pc, chord.quality, chord.bass_pc
                 candidates = ([i % 12 + (pitch // 12) * 12 for i in Acchorder.pc_maps[root]] +
                               [i % 12 + (pitch // 12 - 1) * 12 for i in Acchorder.pc_maps[root]])
                 candidate_lists.append(candidates)
 
-            print(f'note = {note}, pitch = {pitch}')
-            for candidates in candidate_lists:
-                print(candidates)
-            print('')
-
             score_map = Acchorder.get_score_map(note, key, candidate_lists, time_weights)
             best_pitch = pitch
             best_score = -10e8
 
-            for item in score_map.items():
-                print(item)
-            print('')
-
             for midi_num, score in score_map.items():
                 if score > best_score:
                     best_pitch = midi_num
