@@ -1,6 +1,6 @@
 from .chord import Chord
 from .timepoints import get_notes_by_beat
-from miditoolkit.midi import containers
+from miditoolkit.midi import containers, parser
 
 
 def get_pitch_map(midi_obj):
@@ -221,7 +221,7 @@ class Dechorder:
         first_chord = chords[0]
 
         if first_chord.is_complete():
-            chord_marker = containers.Marker(text=first_chord, time=0)
+            chord_marker = containers.Marker(text=str(first_chord), time=0)
             midi_obj.markers.append(chord_marker)
         for i, (prev_chord, next_chord) in enumerate(zip(chords[:-1], chords[1:])):
             if prev_chord != next_chord:
@@ -231,3 +231,31 @@ class Dechorder:
 
         return midi_obj
 
+
+def chord_to_midi(chord):
+    if not chord.is_complete():
+        return None
+
+    root_c = 60
+    bass_c = 36
+    root_pc = chord.root_pc
+    chord_map = Dechorder.chord_maps[chord.quality]
+    bass_pc = chord.bass_pc
+
+    return [bass_c + bass_pc] + [root_c + root_pc + i for i in chord_map]
+
+
+def play_chords(midi_obj):
+    default_velocity = 63
+    midi_maps = [chord_to_midi(Chord(marker.text)) for marker in midi_obj.markers]
+    new_midi_obj = parser.MidiFile()
+    new_midi_obj.time_signature_changes.append(containers.TimeSignature(numerator=4, denominator=4, time=0))
+    new_midi_obj.instruments.append(containers.Instrument(program=0, is_drum=False, name='Piano'))
+
+    for midi_map, prev_marker, next_marker in zip(midi_maps, midi_obj.markers[:-1], midi_obj.markers[1:]):
+        for midi_pitch in midi_map:
+            midi_note = containers.Note(start=prev_marker.time, end=next_marker.time, pitch=midi_pitch,
+                                        velocity=default_velocity)
+            new_midi_obj.instruments[0].notes.append(midi_note)
+
+    return new_midi_obj
